<?php
/**
 * Clase SucursalMercadoBL
 *
 * @package    
 * @subpackage 
 * @author     SucursalMercadoBL
 * @version    SVN: $Id: SucursalMercadoBL.class.php,v 1.1 2008/02/08 21:56:44 william.taype Exp $ 
 */
class SucursalMercadoBL{
    
  /**
  * 
  *
  * @param $o_SucursalMercadoBean, objeto de tipo SucursalMercado 
  * @return Boolean
  */
  public function getSucursalMercado(SucursalMercadoBean $o_SucursalMercadoBean){
    
    $o_SucursalMercadoCT = new SucursalMercadoCT();
    return $o_SucursalMercadoCT->seleccionar($o_SucursalMercadoBean);
    
  }
  
  
  
  public function realizarSucursalMercado(SucursalMercadoBean $o_SucursalMercadoBean){
    
    
  }
  
  
   public function busquedaSucursalMercadoDetalle(SucursalMercadoBean $o_SucursalMercadoBean){
    
    $tmp_ObjSucursalMercado = $this->getSucursalMercado($o_SucursalMercadoBean);
    
    if (is_array($tmp_ObjSucursalMercado)){
      
      foreach ($tmp_ObjSucursalMercado as $iKey => $tmp_SucursalMercadoBean){
        
        $o_MercadoBean = new MercadoBean();
        $o_MercadoBean->setIdMercado($tmp_SucursalMercadoBean->getIdMercado());
        $o_MercadoBL = new MercadoBL();
        $o_MercadoBean = $o_MercadoBL->busquedaMercado($o_MercadoBean);
        
        $tmp_SucursalMercadoBean->setObjectMercado($o_MercadoBean);
        
      }
      
    }else{
      
      if($tmp_ObjSucursalMercado){
      
        $o_MercadoBean = new MercadoBean();
        $o_MercadoBean->setIdMercado($tmp_ObjSucursalMercado->getIdMercado());
        $o_MercadoBL = new MercadoBL();
        $o_MercadoBean = $o_MercadoBL->busquedaMercado($o_MercadoBean);
        
        $tmp_ObjSucursalMercado->setObjectMercado($o_MercadoBean);
        
      }else{
        
        return array();
        
      }
      
    }
    
    return $tmp_ObjSucursalMercado;
   
     
  }
  
  
  
  /*public function busquedaSucursalMercadoDetalle(SucursalMercadoBean $o_SucursalMercadoBean){
    
    $tmp_ObjSucursalMercado = $this->getSucursalMercado($o_SucursalMercadoBean);
    
    if (is_array($tmp_ObjSucursalMercado)){
      
      foreach ($tmp_ObjSucursalMercado as $iKey => $tmp_SucursalMercadoBean){
        
        $o_ColaboradorBean = new ColaboradorBean();
        $o_ColaboradorBean->setIdColaborador($tmp_SucursalMercadoBean->getIdColaborador());
        $o_ColaboradorBL = new ColaboradorBL();
        $o_ColaboradorBean = $o_ColaboradorBL->busquedaColaborador($o_ColaboradorBean);
        
        $tmp_SucursalMercadoBean->setObjectColaborador($o_ColaboradorBean);
        
      }
      
    }else{
      
      if($tmp_ObjSucursalMercado){
      
        $o_ColaboradorBean = new ColaboradorBean();
        $o_ColaboradorBean->setIdColaborador($tmp_ObjSucursalMercado->getIdColaborador());
        $o_ColaboradorBL = new ColaboradorBL();
        $o_ColaboradorBean = $o_ColaboradorBL->busquedaColaborador($o_ColaboradorBean);
        
       $tmp_ObjSucursalMercado->setObjectColaborador($o_ColaboradorBean);
        
      }else{
        
        return array();
        
      }
      
    }
    
    return $tmp_ObjSucursalMercado;
   
     
  }*/
  /**
	* Función que retorna un objeto SucursalMercado o una lista de Objetos de SucursalMercado,
	* dependiendo del parametro que se le envia si este contiene o no el Id de SucursalMercado
	*
	* @param $o_SucursalMercadoBean, es un objeto de tipo SucursalMercado
	* @return Object
	*/
   public function modificarEstadoSucursalMercado(SucursalMercadoBean $o_SucursalMercadoBean){
	  $o_SucursalMercadoCT = new SucursalMercadoCT();
    return $o_SucursalMercadoCT->modificar($o_SucursalMercadoBean);
	}
  
	public function modificarSucursalMercado(SucursalMercadoBean $o_SucursalMercadoBean){
	  $o_SucursalMercadoCT = new SucursalMercadoCT();
    return $o_SucursalMercadoCT->modificar($o_SucursalMercadoBean);
	}
  
    public function eliminarSucursalMercado(SucursalMercadoBean $o_SucursalMercadoBean){
    $o_SucursalMercadoCT = new SucursalMercadoCT();
    return $o_SucursalMercadoCT->eliminar($o_SucursalMercadoBean);
  }
  
   
 
  
  public function insertarSucursalMercado(SucursalMercadoBean $o_SucursalMercadoBean){
     $o_SucursalMercadoCT = new SucursalMercadoCT();
     return $o_SucursalMercadoCT->guardar($o_SucursalMercadoBean);
  }
  
  
}?>